@@ -11,9 +11,9 @@ use Data::Sah::DefaultValueCommon;
 use Exporter qw(import);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-01-20'; # DATE
+our $DATE = '2023-03-30'; # DATE
 our $DIST = 'Data-Sah-DefaultValue'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 our @EXPORT_OK = qw(gen_default_value_code);
 
@@ -97,7 +97,7 @@ Data::Sah::DefaultValue - Default-value rules for Data::Sah
 
 =head1 VERSION
 
-This document describes version 0.002 of Data::Sah::DefaultValue (from Perl distribution Data-Sah-DefaultValue), released on 2023-01-20.
+This document describes version 0.003 of Data::Sah::DefaultValue (from Perl distribution Data-Sah-DefaultValue), released on 2023-03-30.
 
 =head1 SYNOPSIS
 
@@ -184,7 +184,8 @@ Usage:
 Generate code to set default value.
 
 This is mostly for testing. Normally the default value rules will be used from
-L<Data::Sah>.
+L<Data::Sah> via the C<x.perl.default_value_rules> or
+C<x.js.default_value_rules> or C<x.default_value_rules> property.
 
 This function is not exported by default, but exportable.
 
